pub type FieldRenameMap = BTreeMap<String, FieldRenameNode>;Expand description
Rename table for one nesting level of a dictionary’s content: original field name → its short alias and the rename table of its own children.
Aliased Type
pub struct FieldRenameMap { /* private fields */ }