pub type CallerMap = BTreeMap<String, CallerMeta>;Expand description
Maps a local identifier name to the caller it was imported as.
Aliased Type
pub struct CallerMap { /* private fields */ }pub type CallerMap = BTreeMap<String, CallerMeta>;Maps a local identifier name to the caller it was imported as.
pub struct CallerMap { /* private fields */ }