program_to_code

Function program_to_code 

pub fn program_to_code(_program: &Program) -> String
Stand-in used when the code generator is not compiled in (see the debug-output Cargo feature), so debug logs explain how to get the output.